export declare const absoluteLengthUnits: readonly ["cm", "mm", "Q", "in", "pc", "pt", "px"];
export declare type AbsoluteLengthUnit = typeof absoluteLengthUnits[number];
export declare const fontRelativeLengthUnits: readonly ["em", "rem", "ex", "rex", "cap", "rcap", "ch", "rch", "ic", "ric", "lh", "rlh"];
export declare const viewportPercentageLengthUnits: readonly ["vw", "vh", "vi", "vb", "vmin", "vmax", "dvw", "dvh", "dvi", "dvb", "dvmin", "dvmax", "lvw", "lvh", "lvi", "lvb", "lvmin", "lvmax", "svw", "svh", "svi", "svb", "svmin", "svmax"];
export declare type ViewportPercentageLengthUnit = typeof viewportPercentageLengthUnits[number];
export declare const relativeLengthUnits: readonly ["em", "rem", "ex", "rex", "cap", "rcap", "ch", "rch", "ic", "ric", "lh", "rlh", "vw", "vh", "vi", "vb", "vmin", "vmax", "dvw", "dvh", "dvi", "dvb", "dvmin", "dvmax", "lvw", "lvh", "lvi", "lvb", "lvmin", "lvmax", "svw", "svh", "svi", "svb", "svmin", "svmax"];
export declare type RelativeLengthUnit = typeof relativeLengthUnits[number];
export declare const lengthUnits: readonly ["cm", "mm", "Q", "in", "pc", "pt", "px", "em", "rem", "ex", "rex", "cap", "rcap", "ch", "rch", "ic", "ric", "lh", "rlh", "vw", "vh", "vi", "vb", "vmin", "vmax", "dvw", "dvh", "dvi", "dvb", "dvmin", "dvmax", "lvw", "lvh", "lvi", "lvb", "lvmin", "lvmax", "svw", "svh", "svi", "svb", "svmin", "svmax"];
export declare type LengthUnit = typeof lengthUnits[number];
export declare const integerUnits: readonly ["integer"];
export declare type IntegerUnit = typeof numberUnits[number];
export declare const numberUnits: readonly ["number"];
export declare type NumberUnit = typeof numberUnits[number];
export declare const percentageUnits: readonly ["%"];
export declare type PercentageUnit = typeof percentageUnits[number];
export declare const angleUnits: readonly ["deg", "grad", "rad", "turn"];
export declare type AngleUnit = typeof angleUnits[number];
export declare const timeUnits: readonly ["s", "ms"];
export declare type TimeUnit = typeof timeUnits[number];
export declare const frequencyUnits: readonly ["hz", "khz"];
export declare type FrequencyUnit = typeof frequencyUnits[number];
export declare const resolutionUnits: readonly ["dpi", "dpcm", "dppx", "x"];
export declare type ResolutionUnit = typeof resolutionUnits[number];
export declare const dimensionUnits: readonly ["cm", "mm", "Q", "in", "pc", "pt", "px", "em", "rem", "ex", "rex", "cap", "rcap", "ch", "rch", "ic", "ric", "lh", "rlh", "vw", "vh", "vi", "vb", "vmin", "vmax", "dvw", "dvh", "dvi", "dvb", "dvmin", "dvmax", "lvw", "lvh", "lvi", "lvb", "lvmin", "lvmax", "svw", "svh", "svi", "svb", "svmin", "svmax", "deg", "grad", "rad", "turn", "s", "ms", "hz", "khz", "dpi", "dpcm", "dppx", "x"];
export declare type DimensionUnit = typeof dimensionUnits[number];
export declare const cssUnits: readonly ["integer", "number", "%", "cm", "mm", "Q", "in", "pc", "pt", "px", "em", "rem", "ex", "rex", "cap", "rcap", "ch", "rch", "ic", "ric", "lh", "rlh", "vw", "vh", "vi", "vb", "vmin", "vmax", "dvw", "dvh", "dvi", "dvb", "dvmin", "dvmax", "lvw", "lvh", "lvi", "lvb", "lvmin", "lvmax", "svw", "svh", "svi", "svb", "svmin", "svmax", "deg", "grad", "rad", "turn", "s", "ms", "hz", "khz", "dpi", "dpcm", "dppx", "x"];
export declare type CssUnit = typeof cssUnits[number];
declare type UnitWithValue = {
    unit: string;
    value: number;
};
export declare const unitTypes: readonly ["number", "integer", "percentage", "length", "angle", "time", "frequency", "resolution"];
export declare type UnitType = typeof unitTypes[number];
export declare const isNumber: (element: UnitWithValue | string) => boolean;
export declare const getCompatibleUnits: (unit: UnitWithValue | string) => ("number" | "integer" | "percentage" | "length" | "angle" | "time" | "frequency" | "resolution")[];
/** Compare two values with unit.
 * A return value of 0 means that the values are the same.
 * A return value of 1 means that the first value is larger.
 * A return value of -1 means that the second value is larger.
 * A return value of undefined means that the values are not comparable, but compatible.
 * Throws an error if the values are not compatible
 */
export declare const compareValues: (a: UnitWithValue, b: UnitWithValue) => 0 | 1 | -1 | undefined;
export declare const checkAdditionCompatibility: (...elements: Array<UnitWithValue | UnitType[]>) => ("number" | "integer" | "percentage" | "length" | "angle" | "time" | "frequency" | "resolution")[];
export declare const checkMultiplicationCompatibility: (...elements: Array<UnitWithValue | UnitType[]>) => ("number" | "integer" | "percentage" | "length" | "angle" | "time" | "frequency" | "resolution")[];
export declare const checkMinMaxCompatibility: (...elements: Array<UnitWithValue | UnitType[]>) => ("number" | "integer" | "percentage" | "length" | "angle" | "time" | "frequency" | "resolution")[];
export declare const checkValidDivider: (element: UnitWithValue | UnitType[]) => boolean;
export {};
